#!/bin/sh
# script shell that copy local files from CTD SBE19+ to network or external drive
# for FILAMENTOS cruise, IMARPE/IRD PERU feb 2008
# $Id$
#

# declare variables
# -----------------
PREFIX="fila1"
SOURCE="/cygdrive/c/seasoft/filamentos/sbe19+"
DEST_RAW="/cygdrive/d/CAMPAGNES/FILAMENTOS/data-raw/CTD/SBE19+"
DEST_PROCESS="/cygdrive/d/CAMPAGNES/FILAMENTOS/data-processing/CTD/SBE19+"

# test argument gived in command line
# -----------------------------------
if [ $# -lt 1 -o $# -gt 2 ]; then
  echo "usage: ./copie-ctd.sh start <end>"
  echo "ex:    ./copie-ctd.sh 20"
  echo "ex:    ./copie-ctd.sh 1 25"
  exit
fi

# Declare variables and/or give them attributes.
# The  variable  is  treated as an integer; arithmetic evaluation is performed
# when the variable is assigned a value.
# ----------------------------------------------------------------------------
typeset -i start=$1
typeset -i st=$start

# in case off one argument, one station to process
# ------------------------------------------------
if [ $# -eq 1 ]; then
  typeset -i end=$1
else
  typeset -i end=$2
fi

# stop processing when station <= end ($2)
# ------------------------------------------
while [ $st -le $end ]; do

  # traite le cas des station de 1 a 10
  # -----------------------------------
  if [ $st -lt 10 ]; then
  	STATION="${PREFIX}00${st}"
  elif [ $st -ge 10 -a $st -lt 100 ]; then
    STATION="${PREFIX}0${st}"
  else	  
    STATION="${PREFIX}${st}"
  fi
  
  # test if station exist
  # ---------------------
  if [ -f "${SOURCE}/data/${STATION}.hex" ]; then	
  
  	# do processing when station >= start ($1) 
  	# ----------------------------------------------
    if [ $st -ge $start ] ; then
      echo "Processing station: ${STATION}"

			# copy to data-raw
			# ----------------
      cp -upv ${SOURCE}/data/${STATION}.hex ${DEST_RAW}/${STATION}.hex

			# copy to data-processing
			# -----------------------
      cp -upv ${SOURCE}/data/${STATION}.hex ${DEST_PROCESS}/data/${STATION}.hex
      cp -upv ${SOURCE}/data/${STATION}.cnv ${DEST_PROCESS}/data/${STATION}.cnv
      cp -upv ${SOURCE}/data/${STATION}.asc ${DEST_PROCESS}/data/${STATION}.asc
      cp -upv ${SOURCE}/data/${STATION}.hdr ${DEST_PROCESS}/data/${STATION}.hdr
      cp -upv ${SOURCE}/plots/${STATION}*.jpg ${DEST_PROCESS}/plots
#      cp -upv ${SOURCE}/odv/* ${DEST_PROCESS}/odv
#      cp -upv ${SOURCE}/coupes/*.png ${DEST_PROCESS}/coupes 
#      cp -upv ${SOURCE}/coupes/*.m ${DEST_PROCESS}/coupes 
      cp -upv ${SOURCE}/filamentos1?ctd* ${DEST_PROCESS}
    fi
	else
		echo "Processing station: ${STATION}: file ${STATION}.hex missing ..."
	fi
  st=st+1
done

