#!/usr/bin/perl -w
#
# tsg_filamentos.pl   J Grelet IRD feb 2008
# $Id$
# analyse fichiers sample.txt acquis sur l'Oyala, filamentos
# usage ./tsg_filamentos.pl 
#
#
# 

use strict;
use Time::Local;
use Date::Manip;
use File::Basename;
use Getopt::Std;

#------------------------------------------------------------------------------
# Les variables globales
#------------------------------------------------------------------------------

my $sst_hdr_file   = "filamentos1.tsg";
my $sst_file       = "filamentos_tsg";
my $tsgqc_file     = "filamentos_tsg.txt";

my $cruise     = "FILAMENTOS1";
my $ship       = "OYALA";
my $institute  = "IMARPE";
my $sst_instrument = "CUSTOM";

# handles de fichiers
my ($tsg_hdl,$tsgd_hdl,$mto_hdl,$mtod_hdl);

my ($year,$julien,$time,$f);
my ($lat_s,$lat_deg,$lat_min,$lat_dec);
my ($long_s,$long_deg,$long_min,$long_dec);

# capteurs
my ($date,$heure,$lat,$long,$sst,$sss,$sss_qc,$flu2);

#------------------------------------------------------------------------------
# fonctions de calcul de la position/date
#------------------------------------------------------------------------------
sub position {
  my($deg,$min,$hemi)=@_;
  my $sign = 1;
  if( $hemi eq "S" || $hemi eq "W") {
    $sign = -1;
  }
  return( ( $deg + ( $min / 60 ) ) * $sign ); 
}

sub julian {
  my($jj,$h,$m,$s)=@_;
  #print "$jj $h $m $s\n";
  my $tmp = ( ($h * 3600) + ( $m * 60 ) +$s ) / (1440 * 60);
  return( $jj + $tmp ); 
}

#------------------------------------------------------------------------------
# Debut du programme principal
#------------------------------------------------------------------------------
#&Date_Init( "TZ=UTC","Language=French","DateFormat=non-US" );
&Date_Init( "TZ=UTC" );

if( $#ARGV != -1) {
  print STDERR "usage: tsg_filamentos.pl\n";
  exit 1;
}

#open( SST_FILE,  "+> $sst_hdr_file" ) or die "Can't open file : $sst_hdr_file\n";
open( SSTD_FILE, "+> $sst_file" )     or die "Can't open file : $sst_file\n";
open( SSTQC_FILE, "+> $tsgqc_file" )  or die "Can't open file : $tsgqc_file\n";


#print SST_FILE  "$cruise  $ship  $institute  $sst_instrument\n";
print SSTD_FILE "$cruise  $ship  $institute  $sst_instrument\n";


#print SST_FILE  "   Date     Time      Latitude     Longitude    SSJT    SSPS    FLU2\n";
print SSTD_FILE "YEAR    DAYS      LATX      LONX    SSTP   SSPS   FLU2\n";


# pour la campagne, on traite les donnees tous les jours, donc le directive DATA
# n'est pas utilise, on utilise le nom des fichiers passes en argument
# 
 while( <DATA> ){
   open( FILE, $_ );
   print STDERR "Lit : $_";
#for( $i = 0; $i <= $#ARGV; $i++ ){
#  $path = $ARGV[$i];
#  open( FILE, $path );
#  ($name,$dir) = fileparse $path;
#  print STDERR "Lit : $dir$name\n";
LINE: 
  while( <FILE> ){           # header contient l'entete
    next LINE if $. <= 2;    # saute la premiere ligne d'entete
		#next LINE if $_ eq "\n";   # saute les lignes vides
    #print "Ligne: $_\n";
    (undef,$date,undef,undef,undef,$lat_dec,,undef,undef,$long_dec,undef,undef,undef,$sst,undef,,undef,undef,undef,undef,undef,$sss,undef,undef,undef,undef,undef,undef,$flu2) = split(/\t/);
		#$f = $date . " " . $heure;
    #print "$f\n"; 
    $time=&ParseDate( $date );
    if (! $time) {
      $julien = 1e+36; 
    } 
    else {
      # transforme le day_of_year en julian day
      $julien = &UnixDate($time,"%j") -1;
      $julien=&julian( $julien,
                       &UnixDate($time,"%H"),&UnixDate($time,"%M"),
		       &UnixDate($time,"%S") );
      $year = &UnixDate($time,"%Y");		  
    }
    
    printf SSTD_FILE "%4d %10.9g %+08.4f %+09.4f %6.3f %6.3f %6.4f\n",
                     $year,$julien,$lat_dec,$long_dec,$sst,$sss,$flu2;
    printf SSTQC_FILE "%s %s %+08.4f %+09.4f %6.3f %6.3f  0 %6.3f 0\n",
                     &UnixDate($time,"%d/%m/%Y"),&UnixDate($time,"%H:%M:%S"),
										 $lat_dec,$long_dec,$sst,$sss,$sss;
#    printf SST_FILE "%s20%02d %s  %02d%06.3f %s  %03d%06.3f %s  %6.5g %6.5g %6.5g %6.5g\n", 
#                    substr($date,0,6),substr($date,6),$heure,$lat_deg,$lat_min,$lat_s,
#	            $long_deg,$long_min,$long_s,$sst_cuve,$sss,$cond,$sbe03;
  }
  $. = 0;
}  

close SSTD_FILE;
#close SST_FILE;
close SSTQC_FILE;


__DATA__
data/sample.txt
